import React from 'react';
import { CheckboxProps, InputProps, DropdownProps } from '@bigbinary/neetoui';

type Column = {
  title: string;
  dataIndex: string;
  key: string;
  [key: string]: any;
};
type getColumnDataType = {
  columnData: any[];
  isHidable?: boolean;
  isReOrderable?: boolean;
};
type useColumnsType = {
  localStorageKey: string;
  initialHiddenColumns?: string[];
  initialOrder?: string[];
};
/**
 *
 * It is a helper component that can be used along with the table component to hide
 *
 * and show columns.
 *
 * ![image](https://user-images.githubusercontent.com/32426070/195069324-3cbb4c70-f62b-4080-b4ae-bdeabb449b23.png|height=200|width=300)
 *
 * It's a helper hook used alongside Columns component. It allows you to to
 *
 * interact with the underlying zustand store to hide and show columns.
 *
 * @example 
 *
 * import { useState } from "react";
 * 
 * import { Table } from "@bigbinary/neetoui";
 * import Columns, { useHiddenColumns } from "@bigbinary/neeto-molecules/Columns";
 * 
 * import { DEFAULT_ROW_DATA } from "./constants";
 * 
 * const App = () => {
 *   const localStorageKey = "NEETO_APP_FEATURE_HIDDEN_COLUMNS";
 *   const { hideColumn } = useHiddenColumns(localStorageKey);
 *   const [columns, setColumns] = useState([]);
 *   const DEFAULT_COLUMNS_DATA = [
 *     { title: "Id", dataIndex: "id", key: "id", isHidable: false },
 *     { title: "Name", dataIndex: "name", key: "name", isHidable: false },
 *     {
 *       title: () => (
 *         <>
 *           <span>Email</span>
 *           <Button onClick={() => hideColumn("email")}>Hide</Button>
 *         </>
 *       ),
 *       dataIndex: "email",
 *       key: "email",
 *     },
 *   ];
 * 
 *   return (
 *     <div>
 *       <Columns
 *         columnData={DEFAULT_COLUMNS_DATA}
 *         localStorageKey={localStorageKey}
 *         onChange={setColumns}
 *       />
 *       <Table rowData={DEFAULT_ROW_DATA} columnData={columns} />
 *     </div>
 *   );
 * };
 * @endexample
 * It's a helper hook used alongside Columns component. It allows you to to
 *
 * interact with the underlying zustand store to hide/show columns and store the
 *
 * column order.
 *
 * @example 
 *
 * import { useState } from "react";
 * 
 * import { Table } from "@bigbinary/neetoui";
 * import Columns, { useColumns } from "@bigbinary/neeto-molecules/Columns";
 * 
 * import { DEFAULT_ROW_DATA } from "./constants";
 * 
 * const App = () => {
 *   const localStorageKey = "NEETO_APP_FEATURE_HIDDEN_COLUMNS";
 *   const { hideColumn, getColumnData } = useColumns({
 *     localStorageKey,
 *     initialHiddenColumns,
 *     initialOrder,
 *   });
 *   const [columns, setColumns] = useState([]);
 *   const DEFAULT_COLUMNS_DATA = [
 *     { title: "Id", dataIndex: "id", key: "id", isHidable: false },
 *     { title: "Name", dataIndex: "name", key: "name", isHidable: false },
 *     {
 *       title: () => (
 *         <>
 *           <span>Email</span>
 *           <Button onClick={() => hideColumn("email")}>Hide</Button>
 *         </>
 *       ),
 *       dataIndex: "email",
 *       key: "email",
 *     },
 *   ];
 * 
 *   const handleColumnReorder = columns => {
 *     setColumnOrder(pluck("dataIndex", columns).filter(isNotEmpty));
 *   };
 * 
 *   const columnData = getColumnData({
 *     columnData: columns,
 *     isReOrderable: true,
 *     isHidable: true,
 *   });
 * 
 *   return (
 *     <div>
 *       <Table
 *         rowData={DEFAULT_ROW_DATA}
 *         {...{ columnData }}
 *         onColumnUpdate={handleColumnReorder}
 *       />
 *     </div>
 *   );
 * };
 * @endexample
*/
declare const Columns: React.FC<{
  actionBlock?: React.ReactNode;
  checkboxProps?: CheckboxProps;
  columnData: Column[];
  isSearchable?: boolean;
  localStorageKey: string;
  noColumnMessage?: string;
  onChange: (columns: Column[], hiddenColumns: string[]) => any[];
  searchProps?: InputProps;
} & DropdownProps>;
declare function useHiddenColumns(localStorageKey: string, initialValue?: string[]): {
  hiddenColumns: string[];
  hideColumn: (dataIndex: string) => void;
  showColumn: (dataIndex: string) => void;
  getVisibleColumnData: (columnData: any[]) => any[];
  onColumnDataChange: (columnData: any[]) => void;
};
declare function useColumns({
  localStorageKey,
  initialHiddenColumns,
  initialOrder
}: useColumnsType): {
  hiddenColumns: string[];
  columnOrder: string[];
  hideColumn: (dataIndex: string) => void;
  showColumn: (dataIndex: string) => void;
  getVisibleColumnData: (columnData: any[]) => any[];
  onColumnDataChange: (columnData: any[]) => void;
  getColumnData: ({
    columnData,
    isHidable,
    isReOrderable
  }: getColumnDataType) => any[];
  setColumnOrder: (columns: string[]) => void;
};

export { Columns as default, useColumns, useHiddenColumns };
